Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(295)

Unified Diff: remoting/protocol/session_manager.h

Issue 2798393007: Use SignalingAddress in SignalStrategy insterface. (Closed)
Patch Set: header Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « remoting/protocol/protocol_mock_objects.cc ('k') | remoting/signaling/delegating_signal_strategy.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/protocol/session_manager.h
diff --git a/remoting/protocol/session_manager.h b/remoting/protocol/session_manager.h
index 71c5007f8041975d52bbd02f1d586d89cf2d3248..b8cd08f03114a573dc8b0e1e60b258ddd530de49 100644
--- a/remoting/protocol/session_manager.h
+++ b/remoting/protocol/session_manager.h
@@ -62,6 +62,7 @@
namespace remoting {
+class SignalingAddress;
class SignalStrategy;
namespace protocol {
@@ -108,12 +109,12 @@ class SessionManager : public base::NonThreadSafe {
virtual void set_protocol_config(
std::unique_ptr<CandidateSessionConfig> config) = 0;
- // Tries to create a session to the host |jid|.
+ // Creates a new outgoing session.
//
// |host_jid| is the full jid of the host to connect to.
// |authenticator| is a client authenticator for the session.
virtual std::unique_ptr<Session> Connect(
- const std::string& host_jid,
+ const SignalingAddress& peer_address,
std::unique_ptr<Authenticator> authenticator) = 0;
// Set authenticator factory that should be used to authenticate
« no previous file with comments | « remoting/protocol/protocol_mock_objects.cc ('k') | remoting/signaling/delegating_signal_strategy.h » ('j') | no next file with comments »
@@ -108,12 +109,12 @@ class SessionManager : public base::NonThreadSafe {
//
- // |host_jid| is the full jid of the host to connect to.
- // |authenticator| is a client authenticator for the session.
+ // |peer_address| - full SignalingAddress to connect to.
+ // |authenticator| - client authenticator for the session.
virtual std::unique_ptr<Session> Connect(

Powered by Google App Engine
This is Rietveld 408576698